@@ -22,7 +22,7 @@ import argparse
 from robomachine.strategies import DepthFirstSearchStrategy, RandomStrategy
 
 
-parser = argparse.ArgumentParser(description='RoboMachine 0.5 - a test data generator for Robot Framework',
+parser = argparse.ArgumentParser(description='RoboMachine 0.6 - a test data generator for Robot Framework',
                                  formatter_class=argparse.RawTextHelpFormatter)
 parser.add_argument('input', type=str, help='input file')
 parser.add_argument('--output', '-o', type=str, default=None,
@@ -76,6 +76,15 @@ def _select_strategy(strategy):
         return RandomStrategy
     if strategy == 'dfs':
         return DepthFirstSearchStrategy
+    if strategy == 'allpairs-random':
+        try:
+            from robomachine.allpairsstrategy import AllPairsRandomStrategy
+            return AllPairsRandomStrategy
+        except ImportError:
+            print 'ERROR! allpairs-random strategy needs AllPairs module'
+            print 'please install it from Python Package Index'
+            print 'pip install allpairs'
+            raise
 
 if __name__ == '__main__':
     main()
